@@ -69,6 +69,7 @@ class AnsibleCoreCI(object):
                 'vyos',
                 'junos',
                 'ios',
+                'tower',
             ),
             azure=(
                 'azure',
@@ -166,6 +167,8 @@ class AnsibleCoreCI(object):
             self.instance_id = str(uuid.uuid4())
             self.endpoint = None
 
+            display.sensitive.add(self.instance_id)
+
     def _get_parallels_endpoints(self):
         """
         :rtype: tuple[str]
@@ -299,6 +302,9 @@ class AnsibleCoreCI(object):
                 password=con.get('password'),
             )
 
+            if self.connection.password:
+                display.sensitive.add(self.connection.password)
+
         status = 'running' if self.connection.running else 'starting'
 
         display.info('Status update: %s/%s on instance %s is %s.' %
@@ -453,6 +459,8 @@ class AnsibleCoreCI(object):
         self.endpoint = config['endpoint']
         self.started = True
 
+        display.sensitive.add(self.instance_id)
+
         return True
 
     def _save(self):
